'use strict'

/**
 * Module Dependencies
 */

let stor = require('string-to-regexp')
let assign = require('object-assign')
let gtor = require('glob-to-regexp')
let sliced = require('sliced')
let rregexp = /\/[gmiy]{0,4}$/

/**
 * Export `Switch`
 */

module.exports = Switch

/**
 * Switch
 */

function Switch () {
  let cases = sliced(arguments).reduce(function(obj, arg) {
    return assign(obj, !arg ? {} : arg.cases ? arg.cases : arg)
  }, {})

  let tests = {}
  for (let c in cases) {
    tests[c] = compile(c)
  }

  function switcher (choice) {
    for (let c in cases) {
      if (tests[c](choice)) return cases[c]
    }
  }

  switcher.cases = cases
  return switcher
}

/**
 * Compile the key into an expression
 *
 * @param {String|Regexp} expected
 * @return {Function}
 */

function compile (expected) {
  if (expected[0] === '/' && rregexp.test(expected)) {
    return function test (actual) {
      return stor(expected).test(actual)
  }
  } else {
    return function test (actual) {
      return gtor(expected).test(actual)
    }
  }
}
