'use strict'

/**
 * Module Dependencies
 */

let assert = require('assert')
let Switch = require('./')

describe('switch', function() {
  it('should switch between strings', function() {
    let fn = Switch({
      a: () => 'a',
      b: () => 'b'
    })

    assert.equal(fn('a')(), 'a')
    assert.equal(fn('b')(), 'b')
  })

  it('should switch between regexp', function() {
    let fn = Switch({
      '/team\.\\w+/': () => 'team',
      b: () => 'b'
    })

    assert.equal(fn('team'), null)
    assert.equal(fn('team.hi')(), 'team')
    assert.equal(fn('b')(), 'b')
  })

  it('should support globs', function() {
    let fn = Switch({
      'team.*.hi': () => 'hi',
      'team.*': () => 'team',
      b: () => 'b'
    })

    assert.equal(fn('team'), null)
    assert.equal(fn('team.hello')(), 'team')
    assert.equal(fn('team.hello.hi')(), 'hi')
    assert.equal(fn('b')(), 'b')
  })

  it('should support "default" via star', function() {
    let fn = Switch({
      a: () => 'a',
      b: () => 'b',
      '*': () => 'default'
    })

    assert.equal(fn('bla blah')(), 'default')
    assert.equal(fn('a')(), 'a')
    assert.equal(fn('b')(), 'b')
  })

  it('should be composable', function() {
    let a = Switch({
      a: () => 'a',
      b: () => 'b'
    })

    let b = Switch({
      c: () => 'c',
      d: () => 'd'
    })

    let fn = Switch(a, b)
    assert.equal(fn('a')(), 'a')
    assert.equal(fn('b')(), 'b')
    assert.equal(fn('c')(), 'c')
    assert.equal(fn('d')(), 'd')
  })
})
